import { defineStore } from 'pinia'
import { dictAll, getDictionaryTree } from '@/http/apis/commonApi'

export const useDictStore = defineStore('dictionaries', {
  state: () => {
    return {
      uploadUrl: '/pm/file/upload',
      commonDicts: [],
      dictList: [],
      tagList: [],
      globalDicts: {
        // 四大体系
        fourSystem: {
          1: '业务应用',
          2: '应用支撑',
          3: '数据资源',
          4: '基础设施'
        },
        // 应用类型
        applicationType: {
          1: '办公类系统',
          2: '业务应用类系统',
          3: '门户网站',
          4: '宣传微博/微信公众号',
          5: '硬件类系统',
          6: '工具类系统',
          7: '其他'
        },
        // 业务领域--应用
        businessField: {
          1: '商务',
          2: '外事',
          3: '金融',
          4: '口岸',
          5: '公安',
          6: '教育',
          7: '卫生健康',
          8: '医疗保障',
          9: '民政',
          10: '人力资源和社会保障',
          11: '退役军人事务',
          12: '生态环境',
          13: '住房和城乡建设',
          14: '市场监管',
          15: '知识产权',
          16: '药品监管',
          17: '人民防空',
          18: '司法行政',
          19: '综合交通运维',
          20: '国有资产监管',
          21: '综合行政法',
          22: '财政'
        },
        // 数改系统--应用
        digitalModifySystem: {
          1: '党政机关整体智治',
          2: '数字政府',
          3: '数字经济',
          4: '数字社会',
          7: '数字文化',
          5: '数字法治',
          6: '一体化智能化公共数据平台',
          8: '基层智治'
        },
        // 发布端-应用
        publisher: {
          1: '浙里办',
          2: '浙政钉',
          3: '数字化改革户',
          4: '支付宝',
          5: '微信',
          6: '网页',
          7: 'PC客户端',
          8: 'APP端'
        },
        useScopeOptions: {
          '0': '机关事业单位人员',
          '0-1': '跨部门跨系统',
          '0-2': '系统内地方各级',
          '0-3': '本部门本级',
          '0-4': '处室内部',
          '0-6': '主管处室内部',
          '0-5': '其他',
          '1': '企业',
          '2': '社会公众',
          '3': '其他'
        },
        // 使用范围-应用
        useScope: [
          {
            value: '0',
            label: '机关事业单位人员',
            children: [
              {
                value: '0-1',
                label: '跨部门跨系统'
              },
              {
                value: '0-2',
                label: '系统内地方各级'
              },
              {
                value: '0-3',
                label: '本部门本级'
              },
              {
                value: '0-4',
                label: '处室内部'
              },
              {
                value: '0-6',
                label: '主管处室内部'
              },
              {
                value: '0-5',
                label: '其他'
              }
            ]
          },
          {
            value: '1',
            label: '企业'
          },
          {
            value: '2',
            label: '社会公众'
          },
          {
            value: '3',
            label: '其他'
          }
        ],
        // 项目状态
        projectStatus: [
          { id: 10001, name: '单位内部审核中' },
          { id: 10002, name: '单位内部审核不通过' },
          { id: 10003, name: '待预审' },
          { id: 10004, name: '省级部门联审中' },
          { id: 10005, name: '省级部门联审不通过' },
          { id: 10006, name: '预审中' },
          { id: 10007, name: '预审不通过' },
          { id: 10008, name: '部门联审中' },
          { id: 10009, name: '部门联审不通过' },
          { id: 10010, name: '年度计划中' },
          { id: 10011, name: '年度计划被暂缓' },
          { id: 10012, name: '方案评审中' },
          { id: 10013, name: '方案评审不通过' },
          { id: 10023, name: '联审意见确认中' },
          { id: 10014, name: '待立项批复' }
        ],
        projectStageOptions: {
          1: '计划库',
          2: '审批库',
          3: '建设库',
          4: '验收库',
          5: '运行库',
          6: '注销库'
        },
        // 综合业务领域
        businessTerritory: {
          1: '党政机关整体智治',
          2: '数字政府',
          3: '数字经济',
          4: '数字社会',
          7: '数字文化',
          5: '数字法治',
          6: '一体化智能化公共数据平台',
          8: '基层智治'
        },
        // 建设层级
        constructionLevel: {
          1: '国家',
          2: '省级',
          3: '市级',
          4: '县（市，区）'
        },

        // 等保级别
        insuranceLevel: {
          1: '一级',
          2: '二级',
          3: '三级',
          4: '四级',
          5: '五级'
        },
        // 网络环境
        netEnvOptions: {
          1: '政务内网', 2: '政务外网', 3: '互联网', 4: '业务专网', 5: '单机'
        },
        // 流程状态
        flowStatusOptions: {
          UNDER_REVIEW: '审核中',
          APPROVED: '审核通过',
          BE_REJECTED: '被驳回',
          BE_BACKED: '被退回',
          WITHDRAW: '被撤回'
        },
        statusOptions: {
          10000: {
            name: '未立项',
            color: 'warning'
          },
          10001: {
            name: '单位内部审核中',
            color: 'warning'
          },
          10002: {
            name: '单位内部审核不通过',
            color: 'danger'
          },
          10003: {
            name: '待预审',
            color: 'warning'
          },
          10004: {
            name: '省级部门联审中',
            color: 'warning'
          },
          10005: {
            name: '省级部门联审不通过',
            color: 'danger'
          },
          10006: {
            name: '预审中',
            color: 'warning'
          },
          10007: {
            name: '预审不通过',
            color: 'danger'
          },
          10008: {
            name: '部门联审中',
            color: 'warning'
          },
          10009: {
            name: '部门联审不通过',
            color: 'danger'
          },
          10010: {
            name: '年度计划中',
            color: 'warning'
          },
          10011: {
            name: '被暂缓',
            color: 'danger'
          },
          10012: {
            name: '方案评审中',
            color: 'warning'
          },
          10013: {
            name: '方案评审不通过',
            color: 'danger'
          },
          10023: {
            name: '联审意见确认中',
            color: 'warning'
          },
          10014: {
            name: '待立项批复',
            color: 'warning'
          },
          10015: {
            name: '待申报',
            color: 'warning'
          },
          10016: {
            name: '方案待申报',
            color: 'warning'
          },
          10017: {
            name: '待预审选择态',
            color: 'warning'
          },
          10018: {
            name: '省级部门联审通过',
            color: 'success'
          },
          10021: {
            name: '待应用注册',
            color: 'warning'
          },
          20000: {
            name: '已立项',
            color: 'success'
          },
          20001: {
            name: '待采购',
            color: 'warning'
          },
          20006: {
            name: '待开工',
            color: 'warning'
          },
          20002: {
            name: '建设中',
            color: 'warning'
          },
          20003: {
            name: '待终验',
            color: 'warning'
          },
          20004: {
            name: '终验审核中',
            color: 'warning'
          },
          20005: {
            name: '终验审核不通过',
            color: 'danger'
          },
          30000: {
            name: '已归档',
            color: 'success'
          },
          30001: {
            name: '已验收',
            color: 'success'
          }
        },
        statusGjOptions: {
          0: {
            name: '已终止',
            color: 'danger'
          },
          1: {
            name: '评审中',
            color: 'warning'
          },
          2: {
            name: '待立项',
            color: 'warning'
          },
          3: {
            name: '已驳回',
            color: 'danger'
          },
          4: {
            name: '已立项',
            color: 'success'
          },
          5: {
            name: '已采购',
            color: 'success'
          },
          6: {
            name: '已初验',
            color: 'success'
          },
          7: {
            name: '已终验',
            color: 'success'
          }
        },
        statusOptionsCascader: [
          {
            name: '未立项',
            color: 'warning',
            code: 10000,
            children: [{
              name: '单位内部审核中',
              color: 'warning',
              code: 10001
            },
            {
              name: '单位内部审核不通过',
              color: 'danger',
              code: 10002
            },
            {
              name: '待预审',
              color: 'warning',
              code: 10003
            },
            {
              name: '省级部门联审中',
              color: 'warning',
              code: 10004
            },
            {
              name: '省级部门联审不通过',
              color: 'danger',
              code: 10005
            },
            {
              name: '省级部门联审通过',
              color: 'success',
              code: 10018
            },
            {
              name: '预审中',
              color: 'warning',
              code: 10006
            },
            {
              name: '预审不通过',
              color: 'danger',
              code: 10007
            },
            // {
            //   name: '待预审选择态',
            //   color: 'warning',
            //   code: 10017
            // },

            {
              name: '部门联审中',
              color: 'warning',
              code: 10008
            },
            {
              name: '部门联审不通过',
              color: 'danger',
              code: 10009
            },
            {
              name: '年度计划中',
              color: 'warning',
              code: 10010
            },
            {
              name: '被暂缓',
              color: 'danger',
              code: 10011
            },
            {
              name: '方案待申报',
              color: 'warning',
              code: 10016
            },
            {
              name: '方案评审中',
              color: 'warning',
              code: 10012
            },
            {
              name: '方案评审不通过',
              color: 'danger',
              code: 10013
            },
            {
              name: '待立项批复',
              color: 'warning',
              code: 10014
            },
            {
              name: '待应用注册',
              color: 'warning',
              code: 10021
            }
            // {
            //   name: '待申报',
            //   color: 'warning',
            //   code: 10015
            // }
            ]
          },

          {
            name: '已立项',
            color: 'success',
            code: 20000,
            children: [{
              name: '待采购',
              color: 'warning',
              code: 20001
            },
            {
              name: '待开工',
              color: 'warning',
              code: 20006
            },
            {
              name: '建设中',
              color: 'warning',
              code: 20002
            },
            {
              name: '待终验',
              color: 'warning',
              code: 20003
            },
            {
              name: '终验审核中',
              color: 'warning',
              code: 20004
            },
            {
              name: '终验审核不通过',
              color: 'danger',
              code: 20005
            }
            ]
          },
          {
            name: '已归档',
            color: 'success',
            code: 30000,
            children: [{
              name: '已验收',
              color: 'success',
              code: 30001
            }]
          }
        ],
        // 项目审核状态
        auditStatusOptions: {
          PENDING: '待审核',
          PASS: '审核通过',
          NO_PASS: '审核不通过'
        },
        reAuditStatusOptions: {
          PENDING: '待审核',
          PASS: '审核通过',
          NOT_PASS: '审核不通过'
        },
        // 专家审核状态
        expertAuditStatusOptions: {
          pending: {
            name: '待审核',
            color: 'warning'
          },
          passed: {
            name: '审核通过',
            color: 'success'
          },
          deny: {
            name: '审核不通过',
            color: 'danger'
          },
          refused: {
            name: '审核不通过',
            color: 'danger'
          }
        },
        // 云类型
        cloudTypeOptions: {
          1: '政务云（非信创）',
          2: '政务云（信创）',
          3: '其他'
        },
        accountAppNameOption: [
          '浙江省网络安全协调指挥平台', '浙江省互联网舆情态势感知系统（一期、二期）', '浙江省委网信办数据融合交换系统', '浙江省委网信办网络生态瞭望哨平台', '浙里网络安全智控应用', '浙江省统一政务咨询投诉举报平台', '舆论引导在线', '民情在线', '浙里人才之家应用', '浙侨全球通服务', '党外人士之家应用', '浙江政协履职服务综合平台', '浙里人大预算国资监督系统', '浙里人大立法综合应用', '全省县乡人大换届选举系统', '浙江省妇联“浙里家·连心桥”', '浙江掌上宗教APP', '浙江宗教信息管理系统', '浙里宗教智治应用', '浙江省大救助信息系统', '浙江省民政厅殡葬管理信息系统', '“浙里长寿”数字化应用', '浙江省“浙里养”智慧养老服务', '浙江省民政厅儿童信息管理系统', '浙江省行政规范性文件管理系统', '浙江法律服务网（浙江省公共法律服务“三台融合”系统）', '浙江公证综合管理系统', '浙江省司法厅法律援助管理系统', '浙江省公共信用数字化应用', '浙江省经济运行监测分析数字化应用', '浙江教育政务服务网', '浙江省退役军人全生命周期管理保障信息系统', '浙江省因公出国（境）一件事系统', '浙江省公安厅反虚假信息诈骗工作平台服务', '浙江省人防办数字人防综合管理系统', '浙江省“一网通办”智慧领事平台系统', '大安全智控应用', '公权力大数据监督应用', '红色根脉强基工程应用', '机构编制数字化监管应用', '军地一体化应用', '民呼我为应用', '七张问题清单应用', '人大代表履职应用', '数智群团应用', '突发快响应用', '协商在线', '浙里干部之家应用', '浙里好干部应用', '浙统云应用', '智能文稿服务应用', '网络媒体传播力测评系统', '浙商在线', '浙里快递监管应用', '浙江省人民调解大数据管理系统', '浙江省城市运行安全数字化管理系统', '浙江省“浙里征放心”房屋征收与补偿信息系统', '浙江省物业行业监管与住宅小区治理系统', '浙里城事共治应用', '浙江省浙里自贸在线系统', '浙江省双碳智治应用', '浙江政务服务网投资项目在线审批监管平台（工程建设项目审批监管系统）', '浙里生态产品价值转化应用', '浙里营商环境无感监测应用', '浙江省域空间治理数字化系统', '浙江省GEP核算应用', '浙里校园安全应用（浙江省校园安全及食品卫生管理系统）', '浙江省小微企业园数字化管理平台系统', '浙江科技大脑系统', '中国浙江网上技术市场3.0系统', '省域空间治理数字化平台', '无废城市在线', '钱塘江流域防洪减灾数字化平台系统', '浙农帮扶应用', '浙江省数字畜牧应用系统', '浙江数字种业系统', '浙江“浙里好玩”文旅公共服务系统', '浙江省人口发展和生育健康服务综合管理平台', '浙江省疫苗与预防接种综合信息系统', '浙江省疫情监测预警系统', '浙江省食品安全综合治理协同应用', '浙江省市场监管省级事项“受办分离”服务系统（浙企通）', '浙江省特种设备安全重大风险防范预警系统', '浙江省食品安全风险管理系统', '浙江省商品市场信息化综合管理系统', '浙江省行政执法监管系统', '浙江e行在线系统（浙江省电动自行车综合治理“一件事”集成改革数字化平台）', '浙江知识产权在线', '浙江省特种设备行政许可审批系统', '浙江省“智慧餐饮安全”信息化数据系统', '全省消防智能接处警和智能指挥系统', '浙江省人社一体化经办系统', '浙江省公安厅内部最多跑一次', '浙江公安情指行一体化平台', '浙江省统计数字化应用系统', '浙江省安全生产风险防控及应急救援平台（工业企业安全生产在线）', '浙江省自然灾害风险防控与应急救援综合集成应用', '浙江省一体化在线政务服务平台（“浙里办”）', '浙江省数字政府综合应用', '杭州市富阳区预付卡数字化监管系统',
          '湖州市南浔区单用途预付卡消费预警及投诉处置系统', '帮农促富应用', '成品油智治应用', '防汛防台在线', '房地产风险智防应用', '工程建设现场管控应用', '工业企业安全在线', '共同富裕示范区统计监测和战略目标管理应用', '海上安全智控应用', '减税降费直达快享应用', '经济调节e本账应用', '居民服务“一卡通”应用', '粮食安全在线', '民生实事应用', '能效倒逼“双碳”协同创新应用', '审计常态化“经济体检”应用', '数字办公厅应用', '数字人民币应用', '危险化学品全生命周期安全在线', '亚运在线', '药品安全在线', '疫情防控精密智控综合集成应用', '应急物资在线', '营商环境集成应用', '有效投资ｅ本账应用', '浙江公平在线', '浙江外卖在线', '浙里办票+浙里报账应用', '浙里单用途商业预付卡服务应用', '浙里好管家应用', '浙食链应用', '浙运安应用', '政府重点工作数字化应用', '政务服务“一网通办”应用', '“互联网+监管”应用', '“九龙联动治水”应用', '全省档案信息资源共享利用系统', '浙江省防伪税控发票系统', '浙江省数字贸易服务应用系统', '浙江省“五企”培育政策统筹和绩效评价系统', '浙江省经信厅产业链一键通系统', '浙江省新智造公共服务应用', '浙江省产业大脑综合支撑系统', '全国网络交易监管平台系统', '浙江省药品安全智慧监管“黑匣子”应用', '浙江省企业服务综合应用', '产业大脑能力中心', '产业一链通应用', '对外贸易应用', '公共资源交易服务应用', '国资运营监管应用', '金融综合服务应用', '科技成果转化在线', '科技攻关在线', '亩均论英雄应用', '企业上市集成服务（凤凰丹穴）应用', '企业综合服务应用（企业码）', '全省统一数据交易服务应用', '商贸流通应用', '丝路投资e路通应用', '要素市场化配置应用', '浙江市场在线', '浙江消保在线（消费宝）', '浙里人力资源应用', '浙里e物流应用', '浙农优品应用', '浙企智造在线', '浙江省数智文明创建应用', '浙文创应用', '志愿浙江应用', '最美浙江人应用', '数字残联', '浙江省慈善服务“码上办”应用系统', '浙江省统一视频语音法律咨询系统', '浙江省农村房屋全生命周期数字化管理系统', '浙家政综合服务系统', '浙里课后服务', '浙江省妇幼健康信息系统', '浙江省院前急救120云调度系统', '浙江省处方信息交换与流转平台', '浙江省电子健康卡管理平台', '浙江省应急物资储备管理系统', '浙江省四港联动系统', '浙江省“浙里畅行”出行信息服务系统', '浙江省“浙运安” 重点营运车辆智控系统', '浙里预防青少年新型违法犯罪综合应用', '农房全生命周期管理服务（农房浙建事）应用', '农经在线', '亲青链应用', '学在浙江应用', '浙江“双减”在线', '浙里安居应用', '浙里畅行应用', '浙里大社保应用', '浙里好家政应用', '浙里护苗应用', '浙里基本公共服务“一键达”应用', '浙里健康应用', '浙里健身应用', '浙里就业创业应用',
          '浙里康养应用', '浙里老兵应用', '浙里民生“关键小事”智能速办应用', '浙里逝安应用', '浙里新市民应用', '浙里药店应用', '浙里医保应用', '浙里有善应用', '浙有善育应用', '浙有众扶应用', '智慧助残应用', '浙里关爱未成年人应用', '浙里文化·版权桥', '浙江省文物博物馆综合管理系统', '非遗在线', '国际传播在线', '红色资源在线', '精品创作在线', '礼堂家应用', '理论在线', '旅游通应用', '品质文化智达惠享应用', '青少年成长守护应用', '全民阅读在线', '全域文明数智通应用', '数智视听应用', '意识形态全链智控应用', '浙里文物应用', '浙里有艺事应用', '浙里有志应用', '浙影通应用', '之江发布应用', '浙江省社会矛盾调处化解协同应用系统 V2.0', '浙江检察移动检务平台', '浙江省普法依法治理管理信息系统', '浙江省统一在线即时法律咨询系统', '浙江省律师（基层法律服务）综合管理系统', '浙江省司法行政基层业务信息化平台', '浙里社区矫正应用', '浙江省司法厅司法鉴定统一受案系统', '浙江省政府法律顾问信息服务系统', '浙江经济领域违法犯罪风险精准预测与治理应用', '浙江省公安机关行政执法与刑事司法衔接信息共享系统', '浙江省高院执行一件事', '浙江省高院跨域办案+区域一体化系统', '浙江省“基层治理四平台”系统', '嘉兴市“综合查一次”数字化系统', '浙江省监狱管理局指挥中心接处警系统', '浙江省监狱管理局刑罚执行系统', '桐乡市浙里安保智控应用', '上城区健全社会矛盾风险防范化解体系重大多跨场景系统', '复议数智应用', '检察大数据法律监督应用', '律师在线', '平安风险预测预警防控应用', '全域数字法治监督应用', '社会矛盾风险防范化解应用', '社会治理综合应用', '现代公共法律服务应用（云公共法律服务中心）', '一屏两端应用（浙法治）', '浙警智治应用', '政法一体化办案应用', '“除险保安”晾晒应用', '“大综合一体化”执法监管数字应用', '“全域数字法院”应用', '浙里未来社区在线', '浙里未来乡村在线'
        ],
        // 民族
        nationList: [
          {
            id: 1,
            info: '汉族',
            value: 1
          },
          {
            id: 2,
            info: '壮族',
            value: 2
          },
          {
            id: 3,
            info: '满族',
            value: 3
          },
          {
            id: 4,
            info: '回族',
            value: 4
          },
          {
            id: 5,
            info: '苗族',
            value: 5
          },
          {
            id: 6,
            info: '维吾尔族',
            value: 6
          },
          {
            id: 7,
            info: '土家族',
            value: 7
          },
          {
            id: 8,
            info: '彝族',
            value: 8
          },
          {
            id: 9,
            info: '蒙古族',
            value: 9
          },
          {
            id: 10,
            info: '藏族',
            value: 10
          },
          {
            id: 11,
            info: '布依族',
            value: 11
          },
          {
            id: 12,
            info: '侗族',
            value: 12
          },
          {
            id: 13,
            info: '瑶族',
            value: 13
          },
          {
            id: 14,
            info: '朝鲜族',
            value: 14
          },
          {
            id: 15,
            info: '白族',
            value: 15
          },
          {
            id: 16,
            info: '哈尼族',
            value: 16
          },
          {
            id: 17,
            info: '哈萨克族',
            value: 17
          },
          {
            id: 18,
            info: '黎族',
            value: 18
          },
          {
            id: 19,
            info: '傣族',
            value: 19
          },
          {
            id: 20,
            info: '畲族',
            value: 20
          },
          {
            id: 21,
            info: '傈僳族',
            value: 21
          },
          {
            id: 22,
            info: '仡佬族',
            value: 22
          },
          {
            id: 23,
            info: '东乡族',
            value: 23
          },
          {
            id: 24,
            info: '高山族',
            value: 24
          },
          {
            id: 25,
            info: '拉祜族',
            value: 25
          },
          {
            id: 26,
            info: '水族',
            value: 26
          },
          {
            id: 27,
            info: '佤族',
            value: 27
          },
          {
            id: 28,
            info: '纳西族',
            value: 28
          },
          {
            id: 29,
            info: '羌族',
            value: 29
          },
          {
            id: 30,
            info: '土族',
            value: 30
          },
          {
            id: 31,
            info: '仫佬族',
            value: 31
          },
          {
            id: 32,
            info: '锡伯族',
            value: 32
          },
          {
            id: 33,
            info: '柯尔克孜族',
            value: 33
          },
          {
            id: 34,
            info: '达斡尔族',
            value: 34
          },
          {
            id: 35,
            info: '景颇族',
            value: 35
          },
          {
            id: 36,
            info: '毛南族',
            value: 36
          },
          {
            id: 37,
            info: '撒拉族',
            value: 37
          },
          {
            id: 38,
            info: '布朗族',
            value: 38
          },
          {
            id: 39,
            info: '塔吉克族',
            value: 39
          },
          {
            id: 40,
            info: '阿昌族',
            value: 40
          },
          {
            id: 41,
            info: '普米族',
            value: 41
          },
          {
            id: 42,
            info: '鄂温克族',
            value: 42
          },
          {
            id: 43,
            info: '怒族',
            value: 43
          },
          {
            id: 44,
            info: '京族',
            value: 44
          },
          {
            id: 45,
            info: '基诺族',
            value: 45
          },
          {
            id: 46,
            info: '德昂族',
            value: 46
          },
          {
            id: 47,
            info: '保安族',
            value: 47
          },
          {
            id: 48,
            info: '俄罗斯族',
            value: 48
          },
          {
            id: 49,
            info: '裕固族',
            value: 49
          },
          {
            id: 50,
            info: '乌孜别克族',
            value: 50
          },
          {
            id: 51,
            info: '门巴族',
            value: 51
          },
          {
            id: 52,
            info: '鄂伦春族',
            value: 52
          },
          {
            id: 53,
            info: '独龙族',
            value: 53
          },
          {
            id: 54,
            info: '塔塔尔族',
            value: 54
          },
          {
            id: 55,
            info: '赫哲族',
            value: 55
          },
          {
            id: 56,
            info: '珞巴族',
            value: 56
          }
        ],
        projectTypeOptions: {
          '01': '首次建设',
          '02': '迭代升级',
          '03': '结转建设',
          '04': '新运维',
          '05': '续运维'
        },
        projectConTypeOptions: {
          '01': '首次建设',
          '02': '迭代升级',
          '03': '结转建设'
        },
        projectOpeOptions: {
          '04': '新运维',
          '05': '续运维'
        },
        filedConditionsOptions: [
          {
            value: 'declareAmount',
            label: '申报金额',
            type: 'range_condition',
            valueType: 'Number',
            judges: {
              '=': '等于',
              '!=': '不等于',
              '>': '大于',
              '>=': '大于等于',
              '<': '小于',
              '<=': '小于等于'
            },
            unit: '万元'
          },
          {
            value: 'isTemporaryAugment',
            label: '是否临时补增',
            valueType: 'Number',
            type: 'bool_condition',
            judges: {
              '=': '等于'
            }
          },
          {
            value: 'isDigitalReform',
            label: '是否数改项目',
            valueType: 'Number',
            type: 'bool_condition',
            judges: {
              '=': '等于'
            }
          },
          {
            value: 'bizDomain',
            label: '数改领域',
            valueType: 'String',
            type: 'value_condition',
            judges: {
              // IN: '包含'
              // NOTIN: '不包含'
              '=': '等于'
            },
            options: {
              1: '党政机关整体智治',
              2: '数字政府',
              3: '数字经济',
              4: '数字社会',
              7: '数字文化',
              5: '数字法治',
              6: '一体化智能化公共数据平台',
              8: '基层智治'
            }
          }
        ],
        // 专家评审结果
        reviewResultOptions: {
          1: '评审通过',
          2: '通过需调整',
          3: '修改方案后重新评审'
        },
        // 评审类型
        meetingTypeOptions: {
          1: '初步方案评审',
          2: '建设方案评审',
          3: '验收评审',
          4: '部门联审',
          5: '公平性审查'
        },
        domainBrainAccountOptions: [
          '发改大脑',
          '民政大脑',
          '司法大脑',
          '人力社保大脑',
          '空间大脑',
          '住建大脑',
          '交通大脑',
          '乡村大脑',
          '市场监管大脑',
          '统计大脑',
          '教育大脑',
          '科技大脑',
          '公安大脑',
          '财政大脑',
          '生态环境大脑',
          '水利大脑',
          '文旅大脑',
          '健康大脑',
          '审计大脑',
          '体育大脑',
          '医保大脑',
          '法院大脑',
          '助残大脑',
          '监督大脑',
          '组工大脑',
          '宣传大脑',
          '统战大脑',
          '商务大脑',
          '应急大脑',
          '金融大脑',
          '药监大脑'
        ],
        // 项目归集
        // 预算来源
        budgetSourceOptions: {
          1: '自有资金',
          2: '政府投资-本级财政资金',
          3: '政府投资-上级补助资金',
          4: '银行贷款',
          5: '其他资金'
        },
        baseProjSetProgOptions: {
          // 项目状态
          1: '未立项',
          2: '已立项-未启动',
          3: '已立项-建设中',
          4: '已立项-已验收',
          5: '已立项-已终止',
          6: '已立项-变更建设中'
        },
        baseProjConsClassOptions: {
          // 建设层级
          1: '国家级',
          2: '省级',
          3: '省本级',
          4: '市级',
          5: '市本级',
          6: '区县',
          7: '乡镇（街道）'
        },
        baseProjBasisOptions: {
          // 立项依据
          1: '国家部委下达任务、相关文件明确建设时间',
          2: '本级及上级领导批示',
          3: '重大任务',
          4: '重大共性问题',
          5: '重大决策',
          6: '普惠性惠企利民',
          7: '其他'
        },
        collBuildLevelOptions: {
          1: '省级',
          2: '市级',
          3: '县（市、区）级',
          4: '乡镇（街道、办事处）级',
          5: '村（社区）级'
        },
        collResultOptions: {
          1: '评审通过',
          2: '通过需调整',
          3: '修改方案后重新评审',
          4: '整合通过',
          5: '项目暂缓',
          6: '建设单位放弃申报',
          7: '其他'
        },
        collEqualLevelOptions: {
          1: '一级',
          2: '二级',
          3: '三级',
          4: '四级',
          5: '五级'
        },
        collPurchaseWay: {
          1: '公开招标',
          2: '邀请招标',
          3: '竞争性磋商',
          4: '竞争性谈判',
          5: '询价',
          6: '单一来源采购',
          7: '其他采购方式'
        },
        // 绩效评价
        // 指标级别
        indexLevelOptions: {
          1: '一级',
          2: '二级',
          3: '三级'
        },
        bxDataOptions: [
          '项目建设必须遵循“统一规则、统一标准、统筹协调、资源共享、注重实效、保障安全”的原则，鼓励探索运用互联网、大数据、人工智能、区块链等技术手段进行行政管理，杜绝盲目投资、重复建设和信息孤岛。',
          '项目建设必须有利于贯彻“最多跑一次”改革理念，有利于强化数字化治理、深化数字化变革和一体推进数字政府、数字经济、数字社会建设，符合省、市政府数字化转型顶层设计。',
          '项目建设必须按照“先急后缓、分步实施”的总体思路，所报建设项目目标明确、业务需求充分。',
          '项目建设必须统筹考虑部门（单位）间的信息资源共享需求，充分利用已建的全市电子政务公共基础设施，整合归并同类项目、避免重复建设。',
          '信息安全建设应同步设计、同步建设、同步测评、同步验收、同步运行。',
          '市级部门信息化专项规划编制应预先做好与全市信息化发展规划的衔接，规划发布后报市大数据局存档，作为项目立项的重要依据。',
          '项目规划应确定量化的技术和业务评价指标，明确各个子系统之间的业务流程和数据流程，及其与市政府信息化各公共平台之间的关系。',
          '项目规划应当制定实施计划、组织管理和保障措施，合理考虑硬件购置、软件开发和系统集成的时间进度，并考虑整体的运维服务需要和内容。',
          '项目单位可常年编制、常年申报本部门项目；项目单位主管部门应做好项目的常年编制、常年申报的组织工作；市大数据局对项目单位主管部门报送的项目随报随审，定期批复。',
          '常年编制，常年申报。项目单位基于本部门业务需求，可常年组织编制项目方案，向项目单位主管部门申请纳入储备库。项目单位主管部门可常年从储备库中挑选项目报送市大数据局评审。每个财政预算单位申报的建设类项目数量原则上每年不超过1个。',
          '随报随审，转入评审。市大数据局对各项目单位主管部门报送的项目开展评审，评审时应征求市委改革办对项目是否有利于贯彻“最多跑一次”改革理念的意见，通过审核后的项目进入评审库，未通过审核的项目退回储备库。',
          '年度计划项目批复：项目单位主管部门按照市大数据局发布的年度计划项目报送通知要求，从评审库中，按轻重缓急选择形成下一年度项目立项需求，报送市大数据局；市大数据局商市委改革办、市财政部门后，经市政府数字化转型领导小组办公室会议审议通过，由市大数据局于每年12月底前批复各部门下一年度项目计划。',
          '动态新增项目批复：确需实施的动态新增项目需经市政府数字化转型领导小组办公室会议审议通过，并报请市政府批准后，进行立项。已进入评审库的，由市大数据局批复该项目并纳入立项库；未进入评审库的，应按年度计划项目立项程序实施。',
          '项目单位按财政规定对项目建设资金单独核算、专款专用；对列入年度计划项目存在无故拖延建设、拒绝提供数据共享、建设程序不规范、整改不落实等情形的，有关单位两年内的项目申报不予受理。',
          '项目立项包括方案编制、方案申报、方案审核、计划批复、建设方案批复和存档备查等环节；项目单位主管部门应当以统筹和整合为原则，开展本部门的年度项目立项工作。',
          '方案中软件投资估算参考国标《软件工程 软件开发成本度量规范》（GB/T 36964-2018）标准折算；硬件投资估算按“湖州政务云”资源服务的计算、存储、网络安全等分类折算；若方案设计新增物理硬件不部署在“湖州政务云”平台的，应提供充分理由及依据。',
          '项目施工周期应严格按照建设方案计划执行，原则上不得超过12个月。',
          '项目单位应严格按照有关法律法规开展采购工作，在对项目施工单位的采购标准中，应明确项目施工单位不得与设计、监理、招标代理、第三方评测等公司有任何股权关系（设计施工一体化项目除外）。',
          '进入评审库、立项库的项目，项目单位不得自行调整、变更或取消项目需求；项目确需调整、变更或取消项目需求的，项目单位应当书面报送市大数据局审核。需求变更必须在该项目招标前完成。',
          '项目单位应根据市大数据局的立项批复意见和市财政部门的预算批复，按照实施计划办理政府采购相关手续，抓紧项目实施；项目采购合同签订后，项目单位应及时将合同报市大数据局存档，同时按月报送实施情况和资金支付情况。',
          '项目建设出现逾期30天以上，项目建设单位应及时向市大数据局报告，视情况提交第三方评估报告，市大数据局会同有关单位依照规定，出具项目整改、暂停建设、撤销的书面意见。项目因目标无法完全实现需要终止的，项目单位按合同法、政府采购法、招投标法等相关法律法规完成终止的有关手续，并向市大数据局和财政部门报送相关材料。',
          '竣工验收应审查批复文件、采购文件（招标文件）和合同履行等情况；以及按规定要求提供的其它材料报告。',
          '项目建设单位应在竣工验收通过后3个月内，将项目全周期档案提交市大数据局存档。',
          '未经竣工验收或者竣工验收不合格的项目，不得交付投入使用；竣工验收不合格项目的建设单位须在3个月内完成整改，并提出竣工复验申请，竣工复验原则上不超过1次。',
          '项目单位应无偿共享公共数据，不得拒绝其他部门提出的合理共享要求；数据按照共享属性分为无条件共享类、受限共享类和非共享类；要求列入受限共享类和非共享类公共数据范围的，应当详细说明理由，并提供有关法律、法规、规章等依据。',
          '项目单位应组织开展项目绩效评价，并将结果报市大数据局、抄送市财政局，作为支持项目运维和后期建设的重要参考依据；市大数据局参照相关文件制度，委托第三方机构适时对各项目单位的信息化项目随机进行绩效评估，评估结果将作为审批项目年度计划的重要依据。',
          '项目建设方案中要体现运维需求，实施阶段要做好运维规划，运营阶段要做好运维管理；项目运行和维护管理实行项目单位负责制；施工单位应当与项目单位签订合同，对项目履行保修责任。',
          '各单位已经建成并投入使用的信息化系统，应按要求迁入湖州政务云并提供数据共享。',
          '市、县（市、区）两级共建或统一招标的项目，按照“统一规划、统一建设、分级承担、分级管理”的原则实施。',
          '项目建设应按照体系化、系统化和规范化的要求，以顶层设计、增量开发、迭代升级为推进模式，加强顶层设计与基层探索，坚持厉行节约、业务协同和数据共享，避免各自为政、自成体系、重复投资、重复建设。项目建设单位在申报项目前要先行与“全省数字化改革项目库”进行比对，凡是省里统建和推出试点（示范）的项目，不得再重复建设，凡是市里已有类似的项目，县（市、区）不再重复建设。',
          '系统建设类项目要调研现有相关系统建设运行情况、网络部署情况、业务量及数据情况等；运行维护类项目要明确需运维的系统建设时间、原投资金额、使用现状和上年运维费用。',
          '项目方案中应进行堵点痛点难点问题分析。 多跨协同应用项目应明确各协同部门相关需求和意见的征集情况，涉及公共服务的应明确企业、群众等社会面的需求和意见征集情况。',
          '项目建设方案应该体现项目整体预期绩效。建设方案应明确项目绩效总体目标和阶段目标，不限于设定在改进服务、提高效率、加强监管、支撑决策、节约成本、用户满意度、制度和理论成果、影响力（推广情况、报道情况、批示）等方面的预期绩效目标，可设定具体绩效指标体系，按定性或定量指标来量化建设成效。',
          '从政府效能、公共服务、用户体验、投入产出比等角度明确项目预期的社会经济效益。明确本项目的实施如何有效解决存在问题。',
          '应用模块要合理划分，逻辑关系要设计清晰，要全面覆盖项目所支撑的业务。应用场景要梳理需求，应按照三张清单、V字模型进行拆解、梳理。'
        ],
        templateTypeOptions: {
          1: '多跨协同类',
          2: '一般业务类',
          3: '硬件通用类',
          4: '软硬集成类'
        },
        operationTypeOptions: {
          'CREATE': '新建',
          'DELETE': '删除',
          'UPDATE': '修改'
        }
      }
    }
  },
  getters: {
    expertTypeDict () {
      return this.getDict('expert_type')
    }, // 专家类型
    politicalDict () {
      return this.getDict('political')
    }, // 政治面貌
    degreeDict () {
      return this.getDict('degree')
    }, // 学位
    eduDict () {
      return this.getDict('edu')
    }, // 学历
    administrativeRankDict () {
      return this.getDict('administrative_rank')
    }, // 行政职级
    jobStatusDict () {
      return this.getDict('job_status')
    }, // 在职状态
    companyAttributeDict () {
      return this.getDict('company_attribute')
    }, // 单位类型
    titleLevelDict () {
      return this.getDict('title_level')
    }, // 职称级别
    recommendedWayDict () {
      return this.getDict('recommended_way')
    }, // 推荐类型
    expertSourceDict () {
      return this.getTagDict('expert_source')
    }, // 专家来源
    goodAtDict () {
      return this.getTagDict('good_at')
    } // 擅长方向
  },
  actions: {
    setDictStore () {
      return new Promise((resolve, reject) => {
        dictAll({ dictionaryTypeList: [], allDict: true })
          .then((res) => {
            this.dictList = res
            resolve(res)
          })
          .catch((err) => {
            reject(err)
          })
      })
    },
    setTagStore () {
      return new Promise((resolve, reject) => {
        getDictionaryTree({ rootTagCodeList: [], allDict: true })
          .then((res) => {
            this.tagList = res
            resolve(res)
          })
          .catch((err) => {
            reject(err)
          })
      })
    },
    getDict (dictionaryName) {
      let opt = this.dictList?.find(i => i.dictionaryName === dictionaryName)
      opt = opt?.dictionaryList?.map(item => (
        {
          dictionaryCode: item.dictionaryCode,
          dictionaryName: item.describe,
          dictionaryFieldName: item.dictionaryType
        }
      ))
      return opt || []
    },
    getTagDict (dictionaryName) {
      let opt = this.tagList.find(i => i.tagCode === dictionaryName)
      opt = opt.children?.map(item => ({
        tagCode: item.tagCode,
        tagName: item.tagName
      }))
      return opt || []
    }
  },
  persist: {
    storage: localStorage,
    paths: ['dictList', 'tagList', 'commonDicts']
  }
})
